@@ -235,7 +235,10 @@ smooth_refresh_get(SmoothRefresh *sm, guint *new_interval)
 
 
 	if(changed) {
-		printf("CPU %3.1f%% current %u (config %u)\n",
+		time_t now;
+		time(&now);
+		printf("%s : CPU %3.1f%% current %u (config %u)\n",
+		       ctime(&now),
 		       sm->last_pcpu,
 		       sm->interval,
 		       *sm->config_interval);
